Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(174)

Unified Diff: src/dateparser.h

Issue 1229903004: Make dates default to the local timezone if none specified (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Actually fix test Created 5 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/dateparser-inl.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/dateparser.h
diff --git a/src/dateparser.h b/src/dateparser.h
index f284590264175bc4a7a79bb87873d89ad3c2d502..15a971a8cca411e7bd97ec35e67323b6602cdc6e 100644
--- a/src/dateparser.h
+++ b/src/dateparser.h
@@ -367,13 +367,13 @@ class DateParser : public AllStatic {
bool is_iso_date_;
};
// Tries to parse an ES5 Date Time String. Returns the next token
// to continue with in the legacy date string parser. If parsing is
// complete, returns DateToken::EndOfInput(). If terminally unsuccessful,
// returns DateToken::Invalid(). Otherwise parsing continues in the
// legacy parser.
template <typename Char>
- static DateParser::DateToken ParseES5DateTime(
+ static DateParser::DateToken ParseES6DateTime(
DateStringTokenizer<Char>* scanner,
DayComposer* day,
TimeComposer* time,
@@ -367,13 +367,13 @@ class DateParser : public AllStatic {
bool is_iso_date_;
};
- // Tries to parse an ES5 Date Time String. Returns the next token
+ // Tries to parse an ES6 Date Time String. Returns the next token
// to continue with in the legacy date string parser. If parsing is
// complete, returns DateToken::EndOfInput(). If terminally unsuccessful,
« no previous file with comments | « no previous file | src/dateparser-inl.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698